import pandas as pd
import logging
from datetime import date
import lxml.etree as et
import time
from utils import split_dataframe
import numpy as np

today = date.today()
today = today.strftime("%d_%m_%Y")

logging.basicConfig(filename=("logs/CDON_" + today +".log"), level=logging.INFO, format='%(asctime)s %(levelname)s:%(message)s', datefmt='%Y-%m-%d %H:%M:%S')
    
def readOldXML_nonvida(file, products):
    entries = []
    counter = 0
    for prod in products.itertuples():
        counter += 1
        entry = {
            'id': 'None',
            'status': 'Online',
            'stock': '0',
            'se': {
                'status': 'Online',
                'deliveryTime': {
                    'min': getattr(prod, 'deliveryTime_min_se'),
                    'max': getattr(prod, 'deliveryTime_max_se')
                    },
            },
            'dk': {
                'status': 'Online',
                'deliveryTime': {
                    'min': getattr(prod, 'deliveryTime_min_dk'),
                    'max': getattr(prod, 'deliveryTime_max_dk')
                    },
            },
            'fi': {
                'status': 'Online',
                'deliveryTime': {
                    'min': getattr(prod, 'deliveryTime_min_fi'),
                    'max': getattr(prod, 'deliveryTime_max_fi')
                    },
            },
        }
        entry['id'] = getattr(prod, 'sku')
        try:
            entry['stock'] = max(int(getattr(prod, 'stock_feed_se')), int(getattr(prod, 'stock_feed_fi')), int(getattr(prod, 'stock_feed_dk')))
            temp_stock = min(int(getattr(prod, 'stock_feed_se')), int(getattr(prod, 'stock_feed_fi')), int(getattr(prod, 'stock_feed_dk')))
        except:
            entry['stock'] = '0'
            temp_stock = 0
        if temp_stock < 4:
            entry['stock'] = '0'
        if entry['stock'] == '0':
            entry['status'] = 'Offline'
            entry['se']['status'] = 'Offline'
            entry['dk']['status'] = 'Offline'
            entry['fi']['status'] = 'Offline'
        
        entries.append(entry)
    save(entries, file)

def save(entries, file):
    marketplace = et.Element("marketplace", xmlns = "https://schemas.cdon.com/product/4.0/4.9.0/availability")
    print(len(entries))
    start_time = time.time()
    counter = 0
    flag = True
    for entry in entries:
        print(f"{counter}/{len(entries)}", end = '\r')
        if counter%10000 == 0:
            print(time.time()-start_time)
            start_time = time.time()
        counter += 1
        product = et.SubElement(marketplace, "product")
        id = et.SubElement(product, 'id')
        id.text = str(entry['id'])
        status = et.SubElement(product, 'status')
        status.text = str(entry['status'])
        stock = et.SubElement(product, 'stock')
        stock.text = str(entry['stock'])
        se = et.SubElement(product, "se")
        se_status = et.SubElement(se, "status")
        se_status.text = str(entry["se"]['status'])
        se_deliveryTime = et.SubElement(se, "deliveryTime")
        se_min = et.SubElement(se_deliveryTime, "min")
        se_min.text = str(entry["se"]['deliveryTime']['min'])
        se_max = et.SubElement(se_deliveryTime, "max")
        se_max.text = str(entry["se"]['deliveryTime']['max'])
        dk = et.SubElement(product, "dk")
        dk_status = et.SubElement(dk, "status")
        dk_status.text = str(entry["dk"]['status'])
        dk_deliveryTime = et.SubElement(dk, "deliveryTime")
        dk_min = et.SubElement(dk_deliveryTime, "min")
        dk_min.text = str(entry["dk"]['deliveryTime']['min'])
        dk_max = et.SubElement(dk_deliveryTime, "max")
        dk_max.text = str(entry["dk"]['deliveryTime']['max'])
        fi = et.SubElement(product, "fi")
        fi_status = et.SubElement(fi, "status")
        fi_status.text = str(entry["fi"]['status'])
        fi_deliveryTime = et.SubElement(fi, "deliveryTime")
        fi_min = et.SubElement(fi_deliveryTime, "min")
        fi_min.text = str(entry["fi"]['deliveryTime']['min'])
        fi_max = et.SubElement(fi_deliveryTime, "max")
        fi_max.text = str(entry["fi"]['deliveryTime']['max'])
    new = et.ElementTree(marketplace)
    with open(file, "wb") as fh:
        new.write(fh, xml_declaration=True, method="xml", encoding='utf-8', pretty_print = True)
    print('stocks saved ' + file)

def execute():
    products = pd.read_csv('download/all_nonvida.csv', sep=';')
    df_split = split_dataframe(products, num_chunks = 5)
    for index, df in enumerate(df_split):
        readOldXML_nonvida(f'feeds/stocks{index}.xml', df)
            
if __name__ == "__main__":
    execute()